plone.app.event
===============

``plone.app.event`` is the calendaring framework for Plone. 

It provides 

- Dexterity behaviors, 
- timezone support, 
- RFC5545 icalendar export, 
- recurrence support, 
- event views 
- and a lot more.

It is part of the `CMS Plone <https://plone.org>`_ and does not need additional installation steps.

Source Code
===========

Contributors please read the document `Contributing to Plone <https://6.docs.plone.org/contributing/index.html>`_

Sources are at the `Plone code repository hosted at Github <https://github.com/plone/plone.dapp.event>`_.
